const t=t=>(r,s)=>{if(r.constructor._observers){if(!r.constructor.hasOwnProperty("_observers")){const t=r.constructor._observers;r.constructor._observers=new Map,t.forEach(((t,s)=>r.constructor._observers.set(s,t)))}}else{r.constructor._observers=new Map;const t=r.updated;r.updated=function(r){t.call(this,r),r.forEach(((t,r)=>{const s=this.constructor._observers.get(r);void 0!==s&&s.call(this,this[r],t)}))}}r.constructor._observers.set(s,t)};function r(t){const r=t.language||"en";return t.translationMetadata.translations[r]&&t.translationMetadata.translations[r].isRTL||!1}function s(t){return r(t)?"rtl":"ltr"}export{r as a,s as c,t as o};
